@@ -1103,10 +1103,11 @@ class HTTPClient:
         return await self.get(r, **kwargs)
 
     async def account_get_multiple_by_user_id(self,
-                                              user_ids: List[str]) -> list:
+                                              user_ids: List[str],
+                                              **kwargs: Any) -> list:
         params = [('accountId', user_id) for user_id in user_ids]
         r = AccountPublicService('/account/api/public/account')
-        return await self.get(r, params=params)
+        return await self.get(r, params=params, **kwargs)
 
     async def account_graphql_get_multiple_by_user_id(self,
                                                       user_ids: List[str],
